/* Add target="_blank" attribute to all hyperlinks generated by the ReST :download: directive.
* This will ensure the links open in a new tab. */

$(document).ready(function () {
  $('a.download').attr('target', '_blank');
});
